import ActivityRouter from './ActivityRouter';
import BacknumberListActivity from './BacknumberListActivity';
import BacknumberDetailActivity from './BacknumberDetailActivity';
import ErrorActivity from './ErrorActivity';

export default class Application {

  constructor(title, menu, content) {
    /**
     * @property {ActivityRouter} route
     */
    this.router = null;

    this.registerRouter();
    this.registerServiceWorker();
  }

  registerRouter() {
    this.router = new ActivityRouter({
      title   : document.getElementById('title'),
      menu    : document.getElementById('menu'),
      content : document.getElementById('content')
    });
    this.router.addRoute('/', BacknumberListActivity);
    this.router.addRoute('/vol/:id', BacknumberDetailActivity);
    this.router.setErrorActivity(ErrorActivity);
    this.router.updateCurrentActivity();
  }

  registerServiceWorker() {
    if (!('serviceWorker' in navigator)) {
      console.error('ServiceWorker is not implmented in this browser.');
      return;
    }

    navigator.serviceWorker.register('/sw.js', {
      scope: '../'
    }).then((registration) => {
      console.info('Successfully registered ServiceWorker.');

      registration.onupdatefound = function(updateEvent) {
        registration.installing.onstatechange = function(event) {
          if (this.state === 'installed') {
            if (registration.active) {
              console.info('SW has been Updated, and restart required.');
            } else {
              console.info('SW has been Installed.');
            }
          }
        };
      };
    }).catch(err => {
      console.error(err);
    });
  }
}
