import Activity from './Activity';

export default class BacknumberDetailActivity extends Activity {

    onStart(params) {
      super.onStart(params);
      this.requestData(params.id);
    }

    onUpdate(params) {
      super.onUpdate(params);
      this.requestData(params.id);
    }

    /**
     * @param {number} id
     */
    requestData(id) {
      let list = '/data/backnumbers.json';
      let detail = `/data/backnumbers/${id}.json`;
      Promise.all([
        fetch(list).then(response => response.json()),
        fetch(detail).then(response => response.json())
      ])
      .then(results => {
        let backnumbers = results.shift();
        let selected = results.shift();
        this.render(backnumbers.items, selected.items, id);
      });
    }

    /**
     * @param {Array<object>} backnumbers
     * @param {Array<object>} selected
     * @param {Number} id
     */
    render(backnumbers, selected, id) {
      let menu = backnumbers.map(item => {
        return `<a class="mdl-navigation__link" href="/vol/${item.id}">
                  Volume.<span>${item.id}</span>
                </a>`;
      }).join('');

      let categories = selected.map(item => {
        return item.category;
      }).filter((category, index, array) => {
        return array.indexOf(category) === index;
      });

      let content = '';
      for (let category of categories) {
        let items = selected.filter(item => {
          return item.category === category;
        }).map(item => {
          return `<div class="mdl-cell mdl-cell--12-col">
                    <h5><a href="${item.url}">${item.title}</a></h5>
                    ${item.description}
                  </div>`;
        }).join('');

        content += `<div class="mdl-cell mdl-cell--12-col">
                      <div class="mdl-grid mdl-shadow--2dp">
                        <div class="mdl-card mdl-cell mdl-cell--12-col">
                          <div class="mdl-card__supporting-text mdl-grid mdl-grid--no-spacing">
                            <h4 class="mdl-cell mdl-cell--12-col">${category}</h4>
                            ${items}
                          </div>
                        </div>
                      </div>
                    </div>`;
      }

      this.context.menu.innerHTML = menu;
      this.context.title.textContent = `Vol.${id}`;
      this.context.content.innerHTML = `<div class="mdl-grid">
                                          ${content}
                                        </div>`;
    }

}
