const CACHE_VERSION = '__VERSION__';
const CACHE_NAME    = 'cache-' + CACHE_VERSION;
const CACHE_URLS    = [
  '/index.html',
  '/app.js',
  '/manifest.json',
  '/images/chrome-touch-icon-192x192.png',
  '/data/backnumbers.json',
  '/material.min.css',
  '/material.min.js'
].concat((function() {
  let ret = [];
  for (let i = 0; i < 50; i++) {
    ret.push(`/data/backnumbers/${i}.json`);
  }
  return ret;
})());

self.addEventListener('install', event => {
  console.debug('sw: onInstall', CACHE_VERSION);

  // add new caches
  let initCaches = caches.open(CACHE_NAME).then(cache => {
    return cache.addAll(CACHE_URLS.map(url => {
      return new Request(url, { credentials: 'include' });
    }));
  });

  // FIXME for debug -> skipWaiting
  event.waitUntil([initCaches, skipWaiting()]);
});

self.addEventListener('activate', event => {
  console.debug('sw: onActivate?', CACHE_VERSION);

  // remove old caches
  let deleteCaches = caches.keys().then(cacheNames => {
    return Promise.all(cacheNames.map(cacheName => {
      if (cacheName !== CACHE_NAME) {
        return caches.delete(cacheName);
      }
    }));
  });
});

self.addEventListener('fetch', event => {
  let req = event.request;
  let detectCache = caches.match(req).then(res => {
    if (res) {
      console.debug('sw: respond cache > ' + req.url);
      return res;
    }

    let accept = event.request.headers.get('accept');
    if (accept && accept.includes('text/html')) {
      console.debug('sw: respond index > ' + req.url);
      return caches.match('/index.html');
    }

    console.debug('sw: new fetch > ' + req.url);
    return fetch(req);
  });

  event.respondWith(detectCache);
});
